package com.sun.jmx.snmp;

import java.net.InetAddress;
import java.util.NoSuchElementException;
import java.util.StringTokenizer;
import java.net.UnknownHostException;
import java.util.Arrays;
import com.sun.jmx.snmp.internal.SnmpTools;
import java.io.Serializable;

public class SnmpEngineId implements Serializable
{
    private static final long serialVersionUID = 5434729655830763317L;
    byte[] engineId;
    String hexString;
    String humanString;
    
    SnmpEngineId(String s) {
        this.engineId = null;
        this.hexString = null;
        this.humanString = null;
        this.engineId = SnmpTools.ascii2binary(s);
        this.hexString = s.toLowerCase();
    }
    
    SnmpEngineId(byte[] engineId) {
        this.engineId = null;
        this.hexString = null;
        this.humanString = null;
        this.engineId = engineId;
        this.hexString = SnmpTools.binary2ascii(engineId).toLowerCase();
    }
    
    public String getReadableId() {
        return this.humanString;
    }
    
    @Override
    public String toString() {
        return this.hexString;
    }
    
    public byte[] getBytes() {
        return this.engineId;
    }
    
    void setStringValue(String humanString) {
        this.humanString = humanString;
    }
    
    static void validateId(String s) throws IllegalArgumentException {
        validateId(SnmpTools.ascii2binary(s));
    }
    
    static void validateId(byte[] array) throws IllegalArgumentException {
        if (array.length < 5) {
            throw new IllegalArgumentException("Id size lower than 5 bytes.");
        }
        if (array.length > 32) {
            throw new IllegalArgumentException("Id size greater than 32 bytes.");
        }
        if ((array[0] & 0x80) == 0x0 && array.length != 12) {
            throw new IllegalArgumentException("Very first bit = 0 and length != 12 octets");
        }
        if (Arrays.equals(new byte[array.length], array)) {
            throw new IllegalArgumentException("Zeroed Id.");
        }
        byte[] array2 = new byte[array.length];
        Arrays.fill(array2, (byte)(-1));
        if (Arrays.equals(array2, array)) {
            throw new IllegalArgumentException("0xFF Id.");
        }
        return;
    }
    
    public static SnmpEngineId createEngineId(byte[] array) throws IllegalArgumentException {
        if (array == null || array.length == 0) {
            return null;
        }
        validateId(array);
        return new SnmpEngineId(array);
    }
    
    public static SnmpEngineId createEngineId() {
        byte[] array = new byte[13];
        int n = 42;
        long n2 = 255L;
        long currentTimeMillis = System.currentTimeMillis();
        array[0] = (byte)((n & 0xFF000000) >> 24);
        int n3 = 0;
        array[n3] |= 0x80;
        array[1] = (byte)((n & 0xFF0000) >> 16);
        array[2] = (byte)((n & 0xFF00) >> 8);
        array[3] = (byte)(n & 0xFF);
        array[4] = 5;
        array[5] = (byte)(int)((currentTimeMillis & n2 << 56) >>> 56);
        array[6] = (byte)(int)((currentTimeMillis & n2 << 48) >>> 48);
        array[7] = (byte)(int)((currentTimeMillis & n2 << 40) >>> 40);
        array[8] = (byte)(int)((currentTimeMillis & n2 << 32) >>> 32);
        array[9] = (byte)(int)((currentTimeMillis & n2 << 24) >>> 24);
        array[10] = (byte)(int)((currentTimeMillis & n2 << 16) >>> 16);
        array[11] = (byte)(int)((currentTimeMillis & n2 << 8) >>> 8);
        array[12] = (byte)(int)(currentTimeMillis & n2);
        return new SnmpEngineId(array);
    }
    
    public SnmpOid toOid() {
        long[] array = new long[this.engineId.length + 1];
        array[0] = (long)this.engineId.length;
        for (int i = 1; i <= this.engineId.length; ++i) {
            array[i] = (long)(this.engineId[i - 1] & 0xFF);
        }
        return new SnmpOid(array);
    }
    
    public static SnmpEngineId createEngineId(String s) throws IllegalArgumentException, UnknownHostException {
        return createEngineId(s, null);
    }
    
    public static SnmpEngineId createEngineId(String s, String str) throws IllegalArgumentException, UnknownHostException {
        if (s == null) {
            return null;
        }
        if (s.startsWith("0x") || s.startsWith("0X")) {
            validateId(s);
            return new SnmpEngineId(s);
        }
        str = ((str == null) ? ":" : str);
        StringTokenizer stringTokenizer = new StringTokenizer(s, str, true);
        int int1 = 161;
        int int2 = 42;
        try {
            String nextToken;
            try {
                nextToken = stringTokenizer.nextToken();
            }
            catch (NoSuchElementException ex) {
                throw new IllegalArgumentException("Passed string is invalid : [" + s + "]");
            }
            InetAddress inetAddress;
            if (!nextToken.equals(str)) {
                inetAddress = InetAddress.getByName(nextToken);
                try {
                    stringTokenizer.nextToken();
                }
                catch (NoSuchElementException ex2) {
                    SnmpEngineId engineId = createEngineId(inetAddress, int1, int2);
                    engineId.setStringValue(s);
                    return engineId;
                }
            }
            else {
                inetAddress = InetAddress.getLocalHost();
            }
            String nextToken2;
            try {
                nextToken2 = stringTokenizer.nextToken();
            }
            catch (NoSuchElementException ex3) {
                SnmpEngineId engineId2 = createEngineId(inetAddress, int1, int2);
                engineId2.setStringValue(s);
                return engineId2;
            }
            if (!nextToken2.equals(str)) {
                int1 = Integer.parseInt(nextToken2);
                try {
                    stringTokenizer.nextToken();
                }
                catch (NoSuchElementException ex4) {
                    SnmpEngineId engineId3 = createEngineId(inetAddress, int1, int2);
                    engineId3.setStringValue(s);
                    return engineId3;
                }
            }
            String nextToken3;
            try {
                nextToken3 = stringTokenizer.nextToken();
            }
            catch (NoSuchElementException ex5) {
                SnmpEngineId engineId4 = createEngineId(inetAddress, int1, int2);
                engineId4.setStringValue(s);
                return engineId4;
            }
            if (!nextToken3.equals(str)) {
                int2 = Integer.parseInt(nextToken3);
            }
            SnmpEngineId engineId5 = createEngineId(inetAddress, int1, int2);
            engineId5.setStringValue(s);
            return engineId5;
        }
        catch (Exception ex6) {
            throw new IllegalArgumentException("Passed string is invalid : [" + s + "]. Check that the used separator [" + str + "] is compatible with IPv6 address format.");
        }
    }
    
    public static SnmpEngineId createEngineId(int n) throws UnknownHostException {
        return createEngineId(InetAddress.getLocalHost(), n, 42);
    }
    
    public static SnmpEngineId createEngineId(InetAddress inetAddress, int n) throws IllegalArgumentException {
        int n2 = 42;
        if (inetAddress == null) {
            throw new IllegalArgumentException("InetAddress is null.");
        }
        return createEngineId(inetAddress, n, n2);
    }
    
    public static SnmpEngineId createEngineId(int n, int n2) throws UnknownHostException {
        return createEngineId(InetAddress.getLocalHost(), n, n2);
    }
    
    public static SnmpEngineId createEngineId(InetAddress inetAddress, int n, int n2) {
        if (inetAddress == null) {
            throw new IllegalArgumentException("InetAddress is null.");
        }
        byte[] address = inetAddress.getAddress();
        byte[] array = new byte[9 + address.length];
        array[0] = (byte)((n2 & 0xFF000000) >> 24);
        int n3 = 0;
        array[n3] |= 0x80;
        array[1] = (byte)((n2 & 0xFF0000) >> 16);
        array[2] = (byte)((n2 & 0xFF00) >> 8);
        array[3] = (byte)(n2 & 0xFF);
        array[4] = 5;
        if (address.length == 4) {
            array[4] = 1;
        }
        if (address.length == 16) {
            array[4] = 2;
        }
        for (int i = 0; i < address.length; ++i) {
            array[i + 5] = address[i];
        }
        array[5 + address.length] = (byte)((n & 0xFF000000) >> 24);
        array[6 + address.length] = (byte)((n & 0xFF0000) >> 16);
        array[7 + address.length] = (byte)((n & 0xFF00) >> 8);
        array[8 + address.length] = (byte)(n & 0xFF);
        return new SnmpEngineId(array);
    }
    
    public static SnmpEngineId createEngineId(int n, InetAddress inetAddress) {
        if (inetAddress == null) {
            throw new IllegalArgumentException("InetAddress is null.");
        }
        byte[] address = inetAddress.getAddress();
        byte[] array = new byte[5 + address.length];
        array[0] = (byte)((n & 0xFF000000) >> 24);
        int n2 = 0;
        array[n2] |= 0x80;
        array[1] = (byte)((n & 0xFF0000) >> 16);
        array[2] = (byte)((n & 0xFF00) >> 8);
        array[3] = (byte)(n & 0xFF);
        if (address.length == 4) {
            array[4] = 1;
        }
        if (address.length == 16) {
            array[4] = 2;
        }
        for (int i = 0; i < address.length; ++i) {
            array[i + 5] = address[i];
        }
        return new SnmpEngineId(array);
    }
    
    public static SnmpEngineId createEngineId(InetAddress inetAddress) {
        return createEngineId(42, inetAddress);
    }
    
    @Override
    public boolean equals(Object o) {
        return o instanceof SnmpEngineId && this.hexString.equals(((SnmpEngineId)o).toString());
    }
    
    @Override
    public int hashCode() {
        return this.hexString.hashCode();
    }
}
